| calculate_pseudocount | R Documentation |
Calculates a pseudocount based on the data to avoid log(0) issues. Uses half of the minimum non-zero value to ensure the pseudocount is smaller than any real value in the data.
calculate_pseudocount(values)
values |
Numeric vector of abundance values |
Pseudocount value (half of minimum non-zero value, or 1e-6 fallback)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.