Run fgsea using the recommended fgseaMultilevel method
Arguments
- ranked_list
A named vector of ranking statistics. Names define the feature universe and must be non-empty and unique; values must be finite and contain at least two distinct statistics.
- gene_sets
A list of pathway gene sets
- min_size
An integer specifying the minimum gene set size
- max_size
An integer specifying the maximum gene set size
- p_adjust_method
P-value adjustment method applied to fgsea raw p-values.