Import Differential Abundance Analysis (DAA) results from MicrobiomeAnalyst
Source:R/import_MicrobiomeAnalyst_daa_results.R
import_MicrobiomeAnalyst_daa_results.RdThis function imports DAA results from an external platform such as MicrobiomeAnalyst. It can be used to compare the results obtained from different platforms.
Usage
import_MicrobiomeAnalyst_daa_results(
file_path = NULL,
data = NULL,
method = "MicrobiomeAnalyst",
group_levels = c("control", "treatment")
)Arguments
- file_path
a character string specifying the path to the CSV file containing the DAA results from MicrobiomeAnalyst. If this parameter is NULL and no data frame is provided, an error will be thrown. Default is NULL.
- data
a data frame containing the DAA results from MicrobiomeAnalyst. Feature identifiers can be stored in a feature/name column or in non-default row names. P-value and adjusted p-value columns are detected by semantic names such as
PvaluesandFDR;Statisticsand fold-change columns are optional. If this parameter is NULL and no file path is provided, an error will be thrown. Default is NULL.- method
a single non-empty character string specifying the method used for the DAA. This will be added as a new column in the returned data frame. Default is "MicrobiomeAnalyst".
- group_levels
a character vector specifying at least two unique group levels for the DAA. These values will be added as new columns in the returned data frame. Default is c("control", "treatment").
Value
a data frame containing the DAA results from MicrobiomeAnalyst with
validated feature, p_values, and p_adjust columns,
optional Statistics and log2_fold_change columns when present
in the imported result, plus additional columns for the method and group
levels.
Examples
# Synthetic export with explicit feature and probability columns.
exported <- data.frame(
feature = c("K00001", "K00002"),
Pvalues = c(0.01, 0.20), FDR = c(0.02, 0.20)
)
daa_results <- import_MicrobiomeAnalyst_daa_results(data = exported)
# The same table can be read from a CSV file.
export_file <- tempfile(fileext = ".csv")
utils::write.csv(exported, export_file, row.names = FALSE)
import_MicrobiomeAnalyst_daa_results(file_path = export_file)
unlink(export_file)