| run_fgsea | R Documentation |
Run fgsea using the recommended fgseaMultilevel method
run_fgsea(ranked_list, gene_sets, min_size = 10, max_size = 500)
ranked_list |
A named vector of ranking statistics |
gene_sets |
A list of pathway gene sets |
min_size |
An integer specifying the minimum gene set size |
max_size |
An integer specifying the maximum gene set size |
A data frame of fgsea results
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.